@@ -175,7 +175,8 @@ enum ERR_PARSE {
     ERR_SPECIAL,      /**< Line contains invalid characters (Error). */
     ERR_TAB,          /**< Line starts with tab when it
                            should not (Error). */
-    ERR_MAXPARSE = ERR_TAB /**< Special value. Size of the error array. */
+    ERR_BADCOMMENT,   /**< End of file while processing comment (Error). */
+    ERR_MAXPARSE = ERR_BADCOMMENT /**< Special value. Size of the error array. */
 };
 
 /**
@@ -331,12 +332,14 @@ enum ERR_PARSE {
  * @{
  */
 
-/** @brief Do not wrap */
-#define INI_PARSE_NOWRAP    0x0001
+/** @brief Suppress multi line value wrapping */
+#define INI_PARSE_NOWRAP           0x0001
 /** @brief No spaces are allowed to the left of the key */
-#define INI_PARSE_NOSPACE   0x0002
+#define INI_PARSE_NOSPACE          0x0002
 /** @brief No tabs are allowed to the left of the key */
-#define INI_PARSE_NOTAB     0x0004
+#define INI_PARSE_NOTAB            0x0004
+/** @brief Do not allow C-style comments */
+#define INI_PARSE_NO_C_COMMENTS    0x0008
 
 /**
  * @}
@@ -479,6 +482,31 @@ int ini_config_file_open(const char *filename,
                          uint32_t metadata_flags,
                          struct ini_cfgfile **file_ctx);
 
+/**
+ * @brief Create a configuration file object using memory buffer.
+ *
+ * Create a file object for parsing a configuration file.
+ * Configuration will use provided memory instead of the actual file.
+ *
+ * A "configuration file object" is different from
+ * a "configuration object". The former stores metadata
+ * about a file the configuration data is read from,
+ * while the latter holds the configuration itself.
+ *
+ * @param[in]  data_buf         In memory configuration data.
+ *                              Needs to be NULL terminated.
+ * @param[in]  data_len         Length of memory data
+ *                              not including terminating NULL.
+ * @param[out] file_ctx         Configuration file object.
+ *
+ * @return 0 - Success.
+ * @return EINVAL - Invalid parameter.
+ * @return ENOMEM - No memory.
+ */
+int ini_config_file_from_mem(void *data_buf,
+                             uint32_t data_len,
+                             struct ini_cfgfile **file_ctx);
+
 /**
  * @brief Close configuration file after parsing
  *
@@ -691,6 +719,9 @@ int ini_config_changed(struct ini_cfgfile *file_ctx1,
  *                              in case of parsing error.
  * @param[in]  collision_flags  Flags that control handling
  *                              of the duplicate sections or keys.
+ * @param[in]  parse_flags      Flags that control parsing process,
+ *                              for example how to handle spaces at
+ *                              the beginning of the line.
  * @param[out] ini_config       Configuration object.
  *
  * @return 0 - Success.
