@@ -79,6 +79,7 @@ struct parser_obj {
     struct ini_comment *ic;
     char *last_read;
     uint32_t last_read_len;
+    int inside_comment;
     char *key;
     uint32_t key_len;
     struct ref_array *raw_lines;
@@ -109,7 +110,7 @@ static int save_error(struct collection_item *el,
                       const char *err_txt);
 
 
-int is_just_spaces(const char *str, uint32_t len)
+static int is_just_spaces(const char *str, uint32_t len)
 {
     uint32_t i;
 
@@ -131,10 +132,10 @@ int is_just_spaces(const char *str, uint32_t len)
  * the line is OK too.
  * Any other character will cause an error.
  */
-int is_allowed_spaces(const char *str,
-                      uint32_t len,
-                      uint32_t parse_flags,
-                      int *error)
+static int is_allowed_spaces(const char *str,
+                             uint32_t len,
+                             uint32_t parse_flags,
+                             int *error)
 {
     uint32_t i;
     int line_ok = 1;
@@ -257,6 +258,7 @@ static int parser_create(struct ini_cfgobj *co,
     new_po->seclinenum = 0;
     new_po->last_read = NULL;
     new_po->last_read_len = 0;
+    new_po->inside_comment = 0;
     new_po->key = NULL;
     new_po->key_len = 0;
     new_po->raw_lines = NULL;
@@ -321,7 +323,11 @@ static int parser_read(struct parser_obj *po)
     if (res == -1) {
         if (feof(po->file)) {
             TRACE_FLOW_STRING("Read nothing", "");
-            action = PARSE_POST;
+            if (po->inside_comment) {
+                action = PARSE_ERROR;
+                po->last_error = ERR_BADCOMMENT;
+            }
+            else action = PARSE_POST;
         }
         else {
             TRACE_ERROR_STRING("Error reading", "");
@@ -970,6 +976,7 @@ static int handle_kvp(struct parser_obj *po, uint32_t *action)
 
     /* Check if we have the key */
     if (*(str) == '=') {
+        TRACE_ERROR_STRING("No key", str);
         po->last_error = ERR_NOKEY;
         *action = PARSE_ERROR;
         return EOK;
@@ -990,12 +997,6 @@ static int handle_kvp(struct parser_obj *po, uint32_t *action)
     while ((len > 0) && (isspace(*(str + len)))) len--;
     /* Adjust length properly */
     len++;
-    if (!len) {
-        TRACE_ERROR_STRING("No key", str);
-        po->last_error = ERR_NOKEY;
-        *action = PARSE_ERROR;
-        return EOK;
-    }
 
     /* Check the key length */
     if(len >= MAX_KEY) {
@@ -1292,6 +1293,73 @@ static int handle_section(struct parser_obj *po, uint32_t *action)
 
 }
 
+static int check_for_comment(char *buffer,
+                             uint32_t buffer_len,
+                             int allow_c_comments,
+                             int *inside_comment)
+{
+    int pos;
+    int is_comment = 0;
+
+    TRACE_FLOW_ENTRY();
+
+    if (*inside_comment) {
+        /* We are already inside the comment
+         * and we are looking for the end of the comment
+         */
+        if (buffer_len) {
+            pos = buffer_len - 1;
+            while(isspace(buffer[pos]) && pos > 0) pos--;
+
+            /* Check for comment at the end of the line */
+            if ((pos > 1) &&
+                (buffer[pos] == '/') &&
+                (buffer[pos - 1] == '*')) {
+                *inside_comment = 0;
+            }
+        }
+        is_comment = 1;
+    }
+    else {
+        /* We do not allow spaces in front of comments
+         * so we expect the comment to start right away.
+         */
+        if ((buffer[0] == '\0') ||
+            (buffer[0] == ';') ||
+            (buffer[0] == '#')) {
+            is_comment = 1;
+        }
+        else if ((allow_c_comments) && (buffer_len > 1)) {
+            if (buffer[0] == '/') {
+                if (buffer[1] == '/') is_comment = 1;
+                else if (buffer[1] == '*') {
+
+                    is_comment = 1;
+                    *inside_comment = 1;
+
+                    /* Here we need to check whether this comment ends
+                     * on this line or not
+                     */
+                    pos = buffer_len - 1;
+                    while(isspace(buffer[pos]) && pos > 0) pos--;
+
+                    /* Check for comment at the end of the line
+                     * but make sure we have at least two asterisks
+                     */
+                    if ((pos > 2) &&
+                        (buffer[pos] == '/') &&
+                        (buffer[pos - 1] == '*')) {
+                        *inside_comment = 0;
+                    }
+                }
+            }
+        }
+    }
+
+    TRACE_FLOW_EXIT();
+    return is_comment;
+}
+
 /* Inspect the line */
 static int parser_inspect(struct parser_obj *po)
 {
@@ -1300,9 +1368,13 @@ static int parser_inspect(struct parser_obj *po)
 
     TRACE_FLOW_ENTRY();
 
-    if ((*(po->last_read) == '\0') ||
-        (*(po->last_read) == ';') ||
-        (*(po->last_read) == '#')) {
+    TRACE_INFO_STRING("Buffer:", po->last_read);
+    TRACE_INFO_NUMBER("In comment:", po->inside_comment);
+
+    if (check_for_comment(po->last_read,
+                          po->last_read_len,
+                          !(po->parse_flags & INI_PARSE_NO_C_COMMENTS),
+                          &(po->inside_comment))) {
 
         error = handle_comment(po, &action);
         if (error) {
@@ -1330,7 +1402,7 @@ static int parser_inspect(struct parser_obj *po)
 
         error = handle_kvp(po, &action);
         if (error) {
-            TRACE_ERROR_NUMBER("Failed to save section", error);
+            TRACE_ERROR_NUMBER("Failed to save kvp", error);
             return error;
         }
     }
@@ -1451,23 +1523,33 @@ static int parser_error(struct parser_obj *po)
         return error;
     }
 
-    /* Exit if there was an error parsing file */
-    if (po->error_level == INI_STOP_ON_ANY) {
+    if (po->last_error == ERR_BADCOMMENT) {
+        /* Avoid endless loop */
+        action = PARSE_DONE;
+        po->ret = EIO;
+    }
+    else if (po->error_level == INI_STOP_ON_ANY) {
         action = PARSE_DONE;
         if (po->last_error & INI_WARNING) po->ret = EILSEQ;
         else po->ret = EIO;
     }
     else if (po->error_level == INI_STOP_ON_NONE) {
-        action = PARSE_READ;
-        if (po->ret == 0) {
-            if (po->last_error & INI_WARNING) po->ret = EILSEQ;
-            else po->ret = EIO;
+        if (po->last_error != ERR_READ) {
+            action = PARSE_READ;
+            if (po->ret == 0) {
+                if (po->last_error & INI_WARNING) po->ret = EILSEQ;
+                else po->ret = EIO;
+            }
+            /* It it was warning but now if it is an error
+             * bump to return code to indicate error. */
+            else if((po->ret == EILSEQ) &&
+                    (!(po->last_error & INI_WARNING))) po->ret = EIO;
+        }
+        else {
+            /* Avoid endless loop */
+            action = PARSE_DONE;
+            po->ret = EIO;
         }
-        /* It it was warning but now if it is an error
-         * bump to return code to indicate error. */
-        else if((po->ret == EILSEQ) &&
-                (!(po->last_error & INI_WARNING))) po->ret = EIO;
-
     }
     else { /* Stop on error */
         if (po->last_error & INI_WARNING) {
@@ -1526,7 +1608,7 @@ static int parser_error(struct parser_obj *po)
 
 
 /* Run parser */
-int parser_run(struct parser_obj *po)
+static int parser_run(struct parser_obj *po)
 {
     int error = EOK;
     struct collection_item *item = NULL;
